exceptiontools.TimeSignatureError
=================================

.. abjad-lineage:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError

.. autoclass:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__delattr__
      ~abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__getitem__
      ~abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__getslice__
      ~abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__repr__
      ~abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__setattr__
      ~abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__setstate__
      ~abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__str__
      ~abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__unicode__

Bases
-----

- :py:class:`exceptions.Exception <exceptions.Exception>`

- :py:class:`exceptions.BaseException <exceptions.BaseException>`

- :py:class:`__builtin__.object <object>`

Special methods
---------------

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__unicode__
   :noindex:
